@@ -18,9 +18,9 @@ import warnings
 
 import google.api_core.client_options
 from google.auth.credentials import AnonymousCredentials  # type: ignore
-from google.cloud._helpers import _LocalStack  # type: ignore
-from google.cloud._helpers import _determine_default_project as _base_default_project  # type: ignore
-from google.cloud.client import ClientWithProject  # type: ignore
+from google.cloud._helpers import _LocalStack
+from google.cloud._helpers import _determine_default_project as _base_default_project
+from google.cloud.client import ClientWithProject
 from google.cloud.datastore.version import __version__
 from google.cloud.datastore import helpers
 from google.cloud.datastore._http import HTTPDatastoreAPI
