@@ -41,35 +41,26 @@ class Transaction(Batch):
     operations (either ``insert`` or ``upsert``) into the same
     mutation, and execute those within a transaction:
 
-    .. testsetup:: txn-put-multi, txn-api
+    .. testsetup:: txn
 
-        import os
         import uuid
 
         from google.cloud import datastore
-        from tests.system.test_system import Config  # system tests
 
-        unique = os.getenv('CIRCLE_BUILD_NUM', str(uuid.uuid4())[0:8])
+        unique = str(uuid.uuid4())[0:8]
         client = datastore.Client(namespace='ns{}'.format(unique))
-        key1 = client.key('_Doctest')
-        entity1 = datastore.Entity(key=key1)
-        entity1['foo'] = 1337
 
-        key2 = client.key('_Doctest', 'abcd1234')
-        entity2 = datastore.Entity(key=key2)
-        entity2['foo'] = 42
-
-        Config.TO_DELETE.extend([entity1, entity2])
-
-    .. doctest:: txn-put-multi
+    .. doctest:: txn
 
+        >>> entity1 = datastore.Entity(client.key('EntityKind', 1234))
+        >>> entity2 = datastore.Entity(client.key('EntityKind', 2345))
         >>> with client.transaction():
         ...     client.put_multi([entity1, entity2])
 
     Because it derives from :class:`~google.cloud.datastore.batch.Batch`,
     :class:`Transaction` also provides :meth:`put` and :meth:`delete` methods:
 
-    .. doctest:: txn-api
+    .. doctest:: txn
 
        >>> with client.transaction() as xact:
        ...     xact.put(entity1)
@@ -78,24 +69,12 @@ class Transaction(Batch):
     By default, the transaction is rolled back if the transaction block
     exits with an error:
 
-    .. testsetup:: txn-error
-
-        import os
-        import uuid
-
-        from google.cloud import datastore
-
-        unique = os.getenv('CIRCLE_BUILD_NUM', str(uuid.uuid4())[0:8])
-        client = datastore.Client(namespace='ns{}'.format(unique))
-
-        def do_some_work():
-            return
-
-        class SomeException(Exception):
-            pass
-
-    .. doctest:: txn-error
+    .. doctest:: txn
 
+        >>> def do_some_work():
+        ...    return
+        >>> class SomeException(Exception):
+        ...    pass
         >>> with client.transaction():
         ...     do_some_work()
         ...     raise SomeException  # rolls back
@@ -112,58 +91,51 @@ class Transaction(Batch):
         entities will not be available at save time!  That means, if you
         try:
 
-        .. testsetup:: txn-entity-key, txn-entity-key-after, txn-manual
-
-            import os
-            import uuid
-
-            from google.cloud import datastore
-            from tests.system.test_system import Config  # system tests
-
-            unique = os.getenv('CIRCLE_BUILD_NUM', str(uuid.uuid4())[0:8])
-            client = datastore.Client(namespace='ns{}'.format(unique))
-
-            def Entity(*args, **kwargs):
-                entity = datastore.Entity(*args, **kwargs)
-                Config.TO_DELETE.append(entity)
-                return entity
-
-        .. doctest:: txn-entity-key
+        .. doctest:: txn
 
             >>> with client.transaction():
-            ...     entity = Entity(key=client.key('Thing'))
-            ...     client.put(entity)
+            ...     thing1 = datastore.Entity(key=client.key('Thing'))
+            ...     client.put(thing1)
 
-       ``entity`` won't have a complete key until the transaction is
+       ``thing1`` won't have a complete key until the transaction is
        committed.
 
        Once you exit the transaction (or call :meth:`commit`), the
        automatically generated ID will be assigned to the entity:
 
-       .. doctest:: txn-entity-key-after
+       .. doctest:: txn
 
           >>> with client.transaction():
-          ...     entity = Entity(key=client.key('Thing'))
-          ...     client.put(entity)
-          ...     print(entity.key.is_partial)  # There is no ID on this key.
+          ...     thing2 = datastore.Entity(key=client.key('Thing'))
+          ...     client.put(thing2)
+          ...     print(thing2.key.is_partial)  # There is no ID on this key.
           ...
           True
-          >>> print(entity.key.is_partial)  # There *is* an ID.
+          >>> print(thing2.key.is_partial)  # There *is* an ID.
           False
 
     If you don't want to use the context manager you can initialize a
     transaction manually:
 
-    .. doctest:: txn-manual
+    .. doctest:: txn
 
        >>> transaction = client.transaction()
        >>> transaction.begin()
        >>>
-       >>> entity = Entity(key=client.key('Thing'))
-       >>> transaction.put(entity)
+       >>> thing3 = datastore.Entity(key=client.key('Thing'))
+       >>> transaction.put(thing3)
        >>>
        >>> transaction.commit()
 
+    .. testcleanup:: txn
+
+        with client.batch() as batch:
+            batch.delete(client.key('EntityKind', 1234))
+            batch.delete(client.key('EntityKind', 2345))
+            batch.delete(thing1.key)
+            batch.delete(thing2.key)
+            batch.delete(thing3.key)
+
     :type client: :class:`google.cloud.datastore.client.Client`
     :param client: the client used to connect to datastore.
 
