@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -267,7 +267,7 @@ class DatastoreAdminAsyncClient:
         request: Union[datastore_admin.ExportEntitiesRequest, dict] = None,
         *,
         project_id: str = None,
-        labels: Dict[str, str] = None,
+        labels: Mapping[str, str] = None,
         entity_filter: datastore_admin.EntityFilter = None,
         output_url_prefix: str = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
@@ -285,7 +285,6 @@ class DatastoreAdminAsyncClient:
         before completion it may leave partial data behind in
         Google Cloud Storage.
 
-
         .. code-block:: python
 
             from google.cloud import datastore_admin_v1
@@ -321,7 +320,7 @@ class DatastoreAdminAsyncClient:
                 This corresponds to the ``project_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            labels (:class:`Dict[str, str]`):
+            labels (:class:`Mapping[str, str]`):
                 Client-assigned labels.
                 This corresponds to the ``labels`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -411,7 +410,12 @@ class DatastoreAdminAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -429,7 +433,7 @@ class DatastoreAdminAsyncClient:
         request: Union[datastore_admin.ImportEntitiesRequest, dict] = None,
         *,
         project_id: str = None,
-        labels: Dict[str, str] = None,
+        labels: Mapping[str, str] = None,
         input_url: str = None,
         entity_filter: datastore_admin.EntityFilter = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
@@ -444,7 +448,6 @@ class DatastoreAdminAsyncClient:
         is possible that a subset of the data has already been
         imported to Cloud Datastore.
 
-
         .. code-block:: python
 
             from google.cloud import datastore_admin_v1
@@ -480,7 +483,7 @@ class DatastoreAdminAsyncClient:
                 This corresponds to the ``project_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            labels (:class:`Dict[str, str]`):
+            labels (:class:`Mapping[str, str]`):
                 Client-assigned labels.
                 This corresponds to the ``labels`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -574,7 +577,12 @@ class DatastoreAdminAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -611,7 +619,6 @@ class DatastoreAdminAsyncClient:
 
         Indexes with a single property cannot be created.
 
-
         .. code-block:: python
 
             from google.cloud import datastore_admin_v1
@@ -665,7 +672,12 @@ class DatastoreAdminAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -701,7 +713,6 @@ class DatastoreAdminAsyncClient:
         [delete][google.datastore.admin.v1.DatastoreAdmin.DeleteIndex]
         again.
 
-
         .. code-block:: python
 
             from google.cloud import datastore_admin_v1
@@ -755,7 +766,12 @@ class DatastoreAdminAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -832,7 +848,12 @@ class DatastoreAdminAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -850,7 +871,6 @@ class DatastoreAdminAsyncClient:
         the list of indexes and may occasionally return stale
         results.
 
-
         .. code-block:: python
 
             from google.cloud import datastore_admin_v1
@@ -911,12 +931,20 @@ class DatastoreAdminAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListIndexesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
