@@ -64,7 +64,7 @@ class CommonMetadata(proto.Message):
         operation_type (google.cloud.datastore_admin_v1.types.OperationType):
             The type of the operation. Can be used as a
             filter in ListOperationsRequest.
-        labels (Dict[str, str]):
+        labels (Mapping[str, str]):
             The client-assigned labels which were
             provided when the operation was created. May
             also include additional labels.
@@ -83,11 +83,31 @@ class CommonMetadata(proto.Message):
         FAILED = 6
         CANCELLED = 7
 
-    start_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    operation_type = proto.Field(proto.ENUM, number=3, enum="OperationType",)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=4,)
-    state = proto.Field(proto.ENUM, number=5, enum=State,)
+    start_time = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    operation_type = proto.Field(
+        proto.ENUM,
+        number=3,
+        enum="OperationType",
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=4,
+    )
+    state = proto.Field(
+        proto.ENUM,
+        number=5,
+        enum=State,
+    )
 
 
 class Progress(proto.Message):
@@ -103,8 +123,14 @@ class Progress(proto.Message):
             unavailable.
     """
 
-    work_completed = proto.Field(proto.INT64, number=1,)
-    work_estimated = proto.Field(proto.INT64, number=2,)
+    work_completed = proto.Field(
+        proto.INT64,
+        number=1,
+    )
+    work_estimated = proto.Field(
+        proto.INT64,
+        number=2,
+    )
 
 
 class ExportEntitiesRequest(proto.Message):
@@ -115,7 +141,7 @@ class ExportEntitiesRequest(proto.Message):
         project_id (str):
             Required. Project ID against which to make
             the request.
-        labels (Dict[str, str]):
+        labels (Mapping[str, str]):
             Client-assigned labels.
         entity_filter (google.cloud.datastore_admin_v1.types.EntityFilter):
             Description of what data from the project is
@@ -145,10 +171,24 @@ class ExportEntitiesRequest(proto.Message):
             without conflict.
     """
 
-    project_id = proto.Field(proto.STRING, number=1,)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=2,)
-    entity_filter = proto.Field(proto.MESSAGE, number=3, message="EntityFilter",)
-    output_url_prefix = proto.Field(proto.STRING, number=4,)
+    project_id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=2,
+    )
+    entity_filter = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="EntityFilter",
+    )
+    output_url_prefix = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class ImportEntitiesRequest(proto.Message):
@@ -159,7 +199,7 @@ class ImportEntitiesRequest(proto.Message):
         project_id (str):
             Required. Project ID against which to make
             the request.
-        labels (Dict[str, str]):
+        labels (Mapping[str, str]):
             Client-assigned labels.
         input_url (str):
             Required. The full resource URL of the external storage
@@ -185,10 +225,24 @@ class ImportEntitiesRequest(proto.Message):
             specified then all entities from the export are imported.
     """
 
-    project_id = proto.Field(proto.STRING, number=1,)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=2,)
-    input_url = proto.Field(proto.STRING, number=3,)
-    entity_filter = proto.Field(proto.MESSAGE, number=4, message="EntityFilter",)
+    project_id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=2,
+    )
+    input_url = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    entity_filter = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message="EntityFilter",
+    )
 
 
 class ExportEntitiesResponse(proto.Message):
@@ -204,7 +258,10 @@ class ExportEntitiesResponse(proto.Message):
             Only present if the operation completed successfully.
     """
 
-    output_url = proto.Field(proto.STRING, number=1,)
+    output_url = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ExportEntitiesMetadata(proto.Message):
@@ -230,11 +287,30 @@ class ExportEntitiesMetadata(proto.Message):
             [google.datastore.admin.v1.ExportEntitiesResponse.output_url][google.datastore.admin.v1.ExportEntitiesResponse.output_url].
     """
 
-    common = proto.Field(proto.MESSAGE, number=1, message="CommonMetadata",)
-    progress_entities = proto.Field(proto.MESSAGE, number=2, message="Progress",)
-    progress_bytes = proto.Field(proto.MESSAGE, number=3, message="Progress",)
-    entity_filter = proto.Field(proto.MESSAGE, number=4, message="EntityFilter",)
-    output_url_prefix = proto.Field(proto.STRING, number=5,)
+    common = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="CommonMetadata",
+    )
+    progress_entities = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="Progress",
+    )
+    progress_bytes = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="Progress",
+    )
+    entity_filter = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message="EntityFilter",
+    )
+    output_url_prefix = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 class ImportEntitiesMetadata(proto.Message):
@@ -259,11 +335,30 @@ class ImportEntitiesMetadata(proto.Message):
             field.
     """
 
-    common = proto.Field(proto.MESSAGE, number=1, message="CommonMetadata",)
-    progress_entities = proto.Field(proto.MESSAGE, number=2, message="Progress",)
-    progress_bytes = proto.Field(proto.MESSAGE, number=3, message="Progress",)
-    entity_filter = proto.Field(proto.MESSAGE, number=4, message="EntityFilter",)
-    input_url = proto.Field(proto.STRING, number=5,)
+    common = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="CommonMetadata",
+    )
+    progress_entities = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="Progress",
+    )
+    progress_bytes = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="Progress",
+    )
+    entity_filter = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message="EntityFilter",
+    )
+    input_url = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 class EntityFilter(proto.Message):
@@ -298,8 +393,14 @@ class EntityFilter(proto.Message):
             Each namespace in this list must be unique.
     """
 
-    kinds = proto.RepeatedField(proto.STRING, number=1,)
-    namespace_ids = proto.RepeatedField(proto.STRING, number=2,)
+    kinds = proto.RepeatedField(
+        proto.STRING,
+        number=1,
+    )
+    namespace_ids = proto.RepeatedField(
+        proto.STRING,
+        number=2,
+    )
 
 
 class CreateIndexRequest(proto.Message):
@@ -316,8 +417,15 @@ class CreateIndexRequest(proto.Message):
             deleted.
     """
 
-    project_id = proto.Field(proto.STRING, number=1,)
-    index = proto.Field(proto.MESSAGE, number=3, message=gda_index.Index,)
+    project_id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    index = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=gda_index.Index,
+    )
 
 
 class DeleteIndexRequest(proto.Message):
@@ -331,8 +439,14 @@ class DeleteIndexRequest(proto.Message):
             The resource ID of the index to delete.
     """
 
-    project_id = proto.Field(proto.STRING, number=1,)
-    index_id = proto.Field(proto.STRING, number=3,)
+    project_id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    index_id = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class GetIndexRequest(proto.Message):
@@ -346,8 +460,14 @@ class GetIndexRequest(proto.Message):
             The resource ID of the index to get.
     """
 
-    project_id = proto.Field(proto.STRING, number=1,)
-    index_id = proto.Field(proto.STRING, number=3,)
+    project_id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    index_id = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class ListIndexesRequest(proto.Message):
@@ -367,10 +487,22 @@ class ListIndexesRequest(proto.Message):
             request, if any.
     """
 
-    project_id = proto.Field(proto.STRING, number=1,)
-    filter = proto.Field(proto.STRING, number=3,)
-    page_size = proto.Field(proto.INT32, number=4,)
-    page_token = proto.Field(proto.STRING, number=5,)
+    project_id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=4,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 class ListIndexesResponse(proto.Message):
@@ -388,8 +520,15 @@ class ListIndexesResponse(proto.Message):
     def raw_page(self):
         return self
 
-    indexes = proto.RepeatedField(proto.MESSAGE, number=1, message=gda_index.Index,)
-    next_page_token = proto.Field(proto.STRING, number=2,)
+    indexes = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=gda_index.Index,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class IndexOperationMetadata(proto.Message):
@@ -407,9 +546,20 @@ class IndexOperationMetadata(proto.Message):
             acting on.
     """
 
-    common = proto.Field(proto.MESSAGE, number=1, message="CommonMetadata",)
-    progress_entities = proto.Field(proto.MESSAGE, number=2, message="Progress",)
-    index_id = proto.Field(proto.STRING, number=3,)
+    common = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="CommonMetadata",
+    )
+    progress_entities = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="Progress",
+    )
+    index_id = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class DatastoreFirestoreMigrationMetadata(proto.Message):
@@ -431,8 +581,16 @@ class DatastoreFirestoreMigrationMetadata(proto.Message):
             Datastore to Cloud Firestore in Datastore mode.
     """
 
-    migration_state = proto.Field(proto.ENUM, number=1, enum=migration.MigrationState,)
-    migration_step = proto.Field(proto.ENUM, number=2, enum=migration.MigrationStep,)
+    migration_state = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=migration.MigrationState,
+    )
+    migration_step = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum=migration.MigrationStep,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
