@@ -230,8 +230,7 @@ class DatastoreGrpcTransport(DatastoreTransport):
 
     @property
     def grpc_channel(self) -> grpc.Channel:
-        """Return the channel designed to connect to this service.
-        """
+        """Return the channel designed to connect to this service."""
         return self._grpc_channel
 
     @property
@@ -420,5 +419,9 @@ class DatastoreGrpcTransport(DatastoreTransport):
     def close(self):
         self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc"
+
 
 __all__ = ("DatastoreGrpcTransport",)
