@@ -84,19 +84,25 @@ def test__get_default_mtls_endpoint():
     assert DatastoreClient._get_default_mtls_endpoint(non_googleapi) == non_googleapi
 
 
-@pytest.mark.parametrize("client_class", [DatastoreClient, DatastoreAsyncClient,])
-def test_datastore_client_from_service_account_info(client_class):
+@pytest.mark.parametrize(
+    "client_class,transport_name",
+    [
+        (DatastoreClient, "grpc"),
+        (DatastoreAsyncClient, "grpc_asyncio"),
+    ],
+)
+def test_datastore_client_from_service_account_info(client_class, transport_name):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = client_class.from_service_account_info(info)
+        client = client_class.from_service_account_info(info, transport=transport_name)
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "datastore.googleapis.com:443"
+        assert client.transport._host == ("datastore.googleapis.com:443")
 
 
 @pytest.mark.parametrize(
@@ -124,22 +130,32 @@ def test_datastore_client_service_account_always_use_jwt(
         use_jwt.assert_not_called()
 
 
-@pytest.mark.parametrize("client_class", [DatastoreClient, DatastoreAsyncClient,])
-def test_datastore_client_from_service_account_file(client_class):
+@pytest.mark.parametrize(
+    "client_class,transport_name",
+    [
+        (DatastoreClient, "grpc"),
+        (DatastoreAsyncClient, "grpc_asyncio"),
+    ],
+)
+def test_datastore_client_from_service_account_file(client_class, transport_name):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
-        client = client_class.from_service_account_file("dummy/file/path.json")
+        client = client_class.from_service_account_file(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        client = client_class.from_service_account_json("dummy/file/path.json")
+        client = client_class.from_service_account_json(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "datastore.googleapis.com:443"
+        assert client.transport._host == ("datastore.googleapis.com:443")
 
 
 def test_datastore_client_get_transport_class():
@@ -477,7 +493,9 @@ def test_datastore_client_client_options_scopes(
     client_class, transport_class, transport_name
 ):
     # Check the case scopes are provided.
-    options = client_options.ClientOptions(scopes=["1", "2"],)
+    options = client_options.ClientOptions(
+        scopes=["1", "2"],
+    )
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
         client = client_class(client_options=options, transport=transport_name)
@@ -608,10 +626,17 @@ def test_datastore_client_create_channel_credentials_file(
         )
 
 
-@pytest.mark.parametrize("request_type", [datastore.LookupRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        datastore.LookupRequest,
+        dict,
+    ],
+)
 def test_lookup(request_type, transport: str = "grpc"):
     client = DatastoreClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -637,7 +662,8 @@ def test_lookup_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = DatastoreClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -653,7 +679,8 @@ async def test_lookup_async(
     transport: str = "grpc_asyncio", request_type=datastore.LookupRequest
 ):
     client = DatastoreAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -683,7 +710,9 @@ async def test_lookup_async_from_dict():
 
 
 def test_lookup_flattened():
-    client = DatastoreClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = DatastoreClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.lookup), "__call__") as call:
@@ -723,7 +752,9 @@ def test_lookup_flattened():
 
 
 def test_lookup_flattened_error():
-    client = DatastoreClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = DatastoreClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -744,7 +775,9 @@ def test_lookup_flattened_error():
 
 @pytest.mark.asyncio
 async def test_lookup_flattened_async():
-    client = DatastoreAsyncClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = DatastoreAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.lookup), "__call__") as call:
@@ -789,7 +822,9 @@ async def test_lookup_flattened_async():
 
 @pytest.mark.asyncio
 async def test_lookup_flattened_error_async():
-    client = DatastoreAsyncClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = DatastoreAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -808,10 +843,17 @@ async def test_lookup_flattened_error_async():
         )
 
 
-@pytest.mark.parametrize("request_type", [datastore.RunQueryRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        datastore.RunQueryRequest,
+        dict,
+    ],
+)
 def test_run_query(request_type, transport: str = "grpc"):
     client = DatastoreClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -837,7 +879,8 @@ def test_run_query_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = DatastoreClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -853,7 +896,8 @@ async def test_run_query_async(
     transport: str = "grpc_asyncio", request_type=datastore.RunQueryRequest
 ):
     client = DatastoreAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -882,10 +926,17 @@ async def test_run_query_async_from_dict():
     await test_run_query_async(request_type=dict)
 
 
-@pytest.mark.parametrize("request_type", [datastore.BeginTransactionRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        datastore.BeginTransactionRequest,
+        dict,
+    ],
+)
 def test_begin_transaction(request_type, transport: str = "grpc"):
     client = DatastoreClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -916,7 +967,8 @@ def test_begin_transaction_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = DatastoreClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -934,7 +986,8 @@ async def test_begin_transaction_async(
     transport: str = "grpc_asyncio", request_type=datastore.BeginTransactionRequest
 ):
     client = DatastoreAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -947,7 +1000,9 @@ async def test_begin_transaction_async(
     ) as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
-            datastore.BeginTransactionResponse(transaction=b"transaction_blob",)
+            datastore.BeginTransactionResponse(
+                transaction=b"transaction_blob",
+            )
         )
         response = await client.begin_transaction(request)
 
@@ -967,7 +1022,9 @@ async def test_begin_transaction_async_from_dict():
 
 
 def test_begin_transaction_flattened():
-    client = DatastoreClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = DatastoreClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -977,7 +1034,9 @@ def test_begin_transaction_flattened():
         call.return_value = datastore.BeginTransactionResponse()
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
-        client.begin_transaction(project_id="project_id_value",)
+        client.begin_transaction(
+            project_id="project_id_value",
+        )
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -989,19 +1048,24 @@ def test_begin_transaction_flattened():
 
 
 def test_begin_transaction_flattened_error():
-    client = DatastoreClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = DatastoreClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
         client.begin_transaction(
-            datastore.BeginTransactionRequest(), project_id="project_id_value",
+            datastore.BeginTransactionRequest(),
+            project_id="project_id_value",
         )
 
 
 @pytest.mark.asyncio
 async def test_begin_transaction_flattened_async():
-    client = DatastoreAsyncClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = DatastoreAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1015,7 +1079,9 @@ async def test_begin_transaction_flattened_async():
         )
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
-        response = await client.begin_transaction(project_id="project_id_value",)
+        response = await client.begin_transaction(
+            project_id="project_id_value",
+        )
 
         # Establish that the underlying call was made with the expected
         # request object values.
@@ -1028,20 +1094,30 @@ async def test_begin_transaction_flattened_async():
 
 @pytest.mark.asyncio
 async def test_begin_transaction_flattened_error_async():
-    client = DatastoreAsyncClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = DatastoreAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
         await client.begin_transaction(
-            datastore.BeginTransactionRequest(), project_id="project_id_value",
+            datastore.BeginTransactionRequest(),
+            project_id="project_id_value",
         )
 
 
-@pytest.mark.parametrize("request_type", [datastore.CommitRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        datastore.CommitRequest,
+        dict,
+    ],
+)
 def test_commit(request_type, transport: str = "grpc"):
     client = DatastoreClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1051,7 +1127,9 @@ def test_commit(request_type, transport: str = "grpc"):
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.commit), "__call__") as call:
         # Designate an appropriate return value for the call.
-        call.return_value = datastore.CommitResponse(index_updates=1389,)
+        call.return_value = datastore.CommitResponse(
+            index_updates=1389,
+        )
         response = client.commit(request)
 
         # Establish that the underlying gRPC stub method was called.
@@ -1068,7 +1146,8 @@ def test_commit_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = DatastoreClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -1084,7 +1163,8 @@ async def test_commit_async(
     transport: str = "grpc_asyncio", request_type=datastore.CommitRequest
 ):
     client = DatastoreAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1095,7 +1175,9 @@ async def test_commit_async(
     with mock.patch.object(type(client.transport.commit), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
-            datastore.CommitResponse(index_updates=1389,)
+            datastore.CommitResponse(
+                index_updates=1389,
+            )
         )
         response = await client.commit(request)
 
@@ -1115,7 +1197,9 @@ async def test_commit_async_from_dict():
 
 
 def test_commit_flattened():
-    client = DatastoreClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = DatastoreClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.commit), "__call__") as call:
@@ -1165,7 +1249,9 @@ def test_commit_flattened():
 
 
 def test_commit_flattened_error():
-    client = DatastoreClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = DatastoreClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1191,7 +1277,9 @@ def test_commit_flattened_error():
 
 @pytest.mark.asyncio
 async def test_commit_flattened_async():
-    client = DatastoreAsyncClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = DatastoreAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.commit), "__call__") as call:
@@ -1246,7 +1334,9 @@ async def test_commit_flattened_async():
 
 @pytest.mark.asyncio
 async def test_commit_flattened_error_async():
-    client = DatastoreAsyncClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = DatastoreAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1270,10 +1360,17 @@ async def test_commit_flattened_error_async():
         )
 
 
-@pytest.mark.parametrize("request_type", [datastore.RollbackRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        datastore.RollbackRequest,
+        dict,
+    ],
+)
 def test_rollback(request_type, transport: str = "grpc"):
     client = DatastoreClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1299,7 +1396,8 @@ def test_rollback_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = DatastoreClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -1315,7 +1413,8 @@ async def test_rollback_async(
     transport: str = "grpc_asyncio", request_type=datastore.RollbackRequest
 ):
     client = DatastoreAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1345,7 +1444,9 @@ async def test_rollback_async_from_dict():
 
 
 def test_rollback_flattened():
-    client = DatastoreClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = DatastoreClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.rollback), "__call__") as call:
@@ -1354,7 +1455,8 @@ def test_rollback_flattened():
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         client.rollback(
-            project_id="project_id_value", transaction=b"transaction_blob",
+            project_id="project_id_value",
+            transaction=b"transaction_blob",
         )
 
         # Establish that the underlying call was made with the expected
@@ -1370,7 +1472,9 @@ def test_rollback_flattened():
 
 
 def test_rollback_flattened_error():
-    client = DatastoreClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = DatastoreClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1384,7 +1488,9 @@ def test_rollback_flattened_error():
 
 @pytest.mark.asyncio
 async def test_rollback_flattened_async():
-    client = DatastoreAsyncClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = DatastoreAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.rollback), "__call__") as call:
@@ -1397,7 +1503,8 @@ async def test_rollback_flattened_async():
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         response = await client.rollback(
-            project_id="project_id_value", transaction=b"transaction_blob",
+            project_id="project_id_value",
+            transaction=b"transaction_blob",
         )
 
         # Establish that the underlying call was made with the expected
@@ -1414,7 +1521,9 @@ async def test_rollback_flattened_async():
 
 @pytest.mark.asyncio
 async def test_rollback_flattened_error_async():
-    client = DatastoreAsyncClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = DatastoreAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1426,10 +1535,17 @@ async def test_rollback_flattened_error_async():
         )
 
 
-@pytest.mark.parametrize("request_type", [datastore.AllocateIdsRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        datastore.AllocateIdsRequest,
+        dict,
+    ],
+)
 def test_allocate_ids(request_type, transport: str = "grpc"):
     client = DatastoreClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1455,7 +1571,8 @@ def test_allocate_ids_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = DatastoreClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -1471,7 +1588,8 @@ async def test_allocate_ids_async(
     transport: str = "grpc_asyncio", request_type=datastore.AllocateIdsRequest
 ):
     client = DatastoreAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1501,7 +1619,9 @@ async def test_allocate_ids_async_from_dict():
 
 
 def test_allocate_ids_flattened():
-    client = DatastoreClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = DatastoreClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.allocate_ids), "__call__") as call:
@@ -1533,7 +1653,9 @@ def test_allocate_ids_flattened():
 
 
 def test_allocate_ids_flattened_error():
-    client = DatastoreClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = DatastoreClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1551,7 +1673,9 @@ def test_allocate_ids_flattened_error():
 
 @pytest.mark.asyncio
 async def test_allocate_ids_flattened_async():
-    client = DatastoreAsyncClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = DatastoreAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.allocate_ids), "__call__") as call:
@@ -1588,7 +1712,9 @@ async def test_allocate_ids_flattened_async():
 
 @pytest.mark.asyncio
 async def test_allocate_ids_flattened_error_async():
-    client = DatastoreAsyncClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = DatastoreAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1604,10 +1730,17 @@ async def test_allocate_ids_flattened_error_async():
         )
 
 
-@pytest.mark.parametrize("request_type", [datastore.ReserveIdsRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        datastore.ReserveIdsRequest,
+        dict,
+    ],
+)
 def test_reserve_ids(request_type, transport: str = "grpc"):
     client = DatastoreClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1633,7 +1766,8 @@ def test_reserve_ids_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = DatastoreClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -1649,7 +1783,8 @@ async def test_reserve_ids_async(
     transport: str = "grpc_asyncio", request_type=datastore.ReserveIdsRequest
 ):
     client = DatastoreAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1679,7 +1814,9 @@ async def test_reserve_ids_async_from_dict():
 
 
 def test_reserve_ids_flattened():
-    client = DatastoreClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = DatastoreClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.reserve_ids), "__call__") as call:
@@ -1711,7 +1848,9 @@ def test_reserve_ids_flattened():
 
 
 def test_reserve_ids_flattened_error():
-    client = DatastoreClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = DatastoreClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1729,7 +1868,9 @@ def test_reserve_ids_flattened_error():
 
 @pytest.mark.asyncio
 async def test_reserve_ids_flattened_async():
-    client = DatastoreAsyncClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = DatastoreAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.reserve_ids), "__call__") as call:
@@ -1766,7 +1907,9 @@ async def test_reserve_ids_flattened_async():
 
 @pytest.mark.asyncio
 async def test_reserve_ids_flattened_error_async():
-    client = DatastoreAsyncClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = DatastoreAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1789,7 +1932,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = DatastoreClient(
-            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(),
+            transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
@@ -1809,7 +1953,10 @@ def test_credentials_transport_error():
     options = client_options.ClientOptions()
     options.api_key = "api_key"
     with pytest.raises(ValueError):
-        client = DatastoreClient(client_options=options, transport=transport,)
+        client = DatastoreClient(
+            client_options=options,
+            transport=transport,
+        )
 
     # It is an error to provide an api_key and a credential.
     options = mock.Mock()
@@ -1825,7 +1972,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = DatastoreClient(
-            client_options={"scopes": ["1", "2"]}, transport=transport,
+            client_options={"scopes": ["1", "2"]},
+            transport=transport,
         )
 
 
@@ -1855,7 +2003,10 @@ def test_transport_get_channel():
 
 @pytest.mark.parametrize(
     "transport_class",
-    [transports.DatastoreGrpcTransport, transports.DatastoreGrpcAsyncIOTransport,],
+    [
+        transports.DatastoreGrpcTransport,
+        transports.DatastoreGrpcAsyncIOTransport,
+    ],
 )
 def test_transport_adc(transport_class):
     # Test default credentials are used if not provided.
@@ -1865,10 +2016,28 @@ def test_transport_adc(transport_class):
         adc.assert_called_once()
 
 
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+    ],
+)
+def test_transport_kind(transport_name):
+    transport = DatastoreClient.get_transport_class(transport_name)(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert transport.kind == transport_name
+
+
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
-    client = DatastoreClient(credentials=ga_credentials.AnonymousCredentials(),)
-    assert isinstance(client.transport, transports.DatastoreGrpcTransport,)
+    client = DatastoreClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert isinstance(
+        client.transport,
+        transports.DatastoreGrpcTransport,
+    )
 
 
 def test_datastore_base_transport_error():
@@ -1908,6 +2077,14 @@ def test_datastore_base_transport():
     with pytest.raises(NotImplementedError):
         transport.close()
 
+    # Catch all for all remaining methods and properties
+    remainder = [
+        "kind",
+    ]
+    for r in remainder:
+        with pytest.raises(NotImplementedError):
+            getattr(transport, r)()
+
 
 def test_datastore_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
@@ -1919,7 +2096,8 @@ def test_datastore_base_transport_with_credentials_file():
         Transport.return_value = None
         load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.DatastoreTransport(
-            credentials_file="credentials.json", quota_project_id="octopus",
+            credentials_file="credentials.json",
+            quota_project_id="octopus",
         )
         load_creds.assert_called_once_with(
             "credentials.json",
@@ -1960,7 +2138,10 @@ def test_datastore_auth_adc():
 
 @pytest.mark.parametrize(
     "transport_class",
-    [transports.DatastoreGrpcTransport, transports.DatastoreGrpcAsyncIOTransport,],
+    [
+        transports.DatastoreGrpcTransport,
+        transports.DatastoreGrpcAsyncIOTransport,
+    ],
 )
 def test_datastore_transport_auth_adc(transport_class):
     # If credentials and host are not provided, the transport class should use
@@ -2058,24 +2239,40 @@ def test_datastore_grpc_transport_client_cert_source_for_mtls(transport_class):
             )
 
 
-def test_datastore_host_no_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_datastore_host_no_port(transport_name):
     client = DatastoreClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="datastore.googleapis.com"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "datastore.googleapis.com:443"
+    assert client.transport._host == ("datastore.googleapis.com:443")
 
 
-def test_datastore_host_with_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_datastore_host_with_port(transport_name):
     client = DatastoreClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="datastore.googleapis.com:8000"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "datastore.googleapis.com:8000"
+    assert client.transport._host == ("datastore.googleapis.com:8000")
 
 
 def test_datastore_grpc_transport_channel():
@@ -2083,7 +2280,8 @@ def test_datastore_grpc_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.DatastoreGrpcTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -2095,7 +2293,8 @@ def test_datastore_grpc_asyncio_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.DatastoreGrpcAsyncIOTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -2216,7 +2415,9 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-    expected = "folders/{folder}".format(folder=folder,)
+    expected = "folders/{folder}".format(
+        folder=folder,
+    )
     actual = DatastoreClient.common_folder_path(folder)
     assert expected == actual
 
@@ -2234,7 +2435,9 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-    expected = "organizations/{organization}".format(organization=organization,)
+    expected = "organizations/{organization}".format(
+        organization=organization,
+    )
     actual = DatastoreClient.common_organization_path(organization)
     assert expected == actual
 
@@ -2252,7 +2455,9 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-    expected = "projects/{project}".format(project=project,)
+    expected = "projects/{project}".format(
+        project=project,
+    )
     actual = DatastoreClient.common_project_path(project)
     assert expected == actual
 
@@ -2272,7 +2477,8 @@ def test_common_location_path():
     project = "winkle"
     location = "nautilus"
     expected = "projects/{project}/locations/{location}".format(
-        project=project, location=location,
+        project=project,
+        location=location,
     )
     actual = DatastoreClient.common_location_path(project, location)
     assert expected == actual
@@ -2297,7 +2503,8 @@ def test_client_with_default_client_info():
         transports.DatastoreTransport, "_prep_wrapped_messages"
     ) as prep:
         client = DatastoreClient(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -2306,7 +2513,8 @@ def test_client_with_default_client_info():
     ) as prep:
         transport_class = DatastoreClient.get_transport_class()
         transport = transport_class(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -2314,7 +2522,8 @@ def test_client_with_default_client_info():
 @pytest.mark.asyncio
 async def test_transport_close_async():
     client = DatastoreAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     with mock.patch.object(
         type(getattr(client.transport, "grpc_channel")), "close"
